@@ -1,5 +1,5 @@
 /*
-  $Id: ServerBase.cxx 9076 2011-03-23 09:41:30Z sloot $
+  $Id: ServerBase.cxx 13726 2011-12-20 11:12:52Z sloot $
   $URL: https://ilk.uvt.nl/svn/trunk/sources/TimblServer/src/ServerBase.cxx $
 
   Copyright (c) 1998 - 2011
@@ -32,6 +32,7 @@
 #endif
 #include <string>
 #include <cerrno>
+#include <cstring>
 #include <cstdlib>
 #include <csignal>
 #include "timbl/TimblAPI.h"
@@ -41,16 +42,20 @@
 #include "timblserver/ServerBase.h"
 
 using namespace std;
+using namespace Timbl;
 
-namespace Timbl {
+namespace TimblServer {
 
+  string Version() { return VERSION; }
+  string VersionName() { return PACKAGE_STRING; }
+    
   static void ShowVersionInfo( std::ostream& os, bool full ){
     os << VERSION;
     if ( full )
       os << ", compiled on " << __DATE__ << ", " << __TIME__;
   }
   
-  string TimblServer::VersionInfo( bool full ){
+  string ServerClass::VersionInfo( bool full ){
     string result;
     ostringstream oss;
     ShowVersionInfo( oss, full );
@@ -58,7 +63,7 @@ namespace Timbl {
     return result; 
   }
 
-  TimblServer::TimblServer(): myLog("TimblServer"){
+  ServerClass::ServerClass(): myLog("TimblServer"){
     debug = false;
     maxConn = 25;
     serverPort = -1;
@@ -67,11 +72,11 @@ namespace Timbl {
     doDaemon = true;
   }  
 
-  TimblServer::~TimblServer(){
+  ServerClass::~ServerClass(){
     delete exp;
   }
 
-  bool TimblServer::getConfig( const string& serverConfigFile ){
+  bool ServerClass::getConfig( const string& serverConfigFile ){
     maxConn = 25;
     serverPort = -1;
     serverProtocol = "tcp";
@@ -202,7 +207,7 @@ namespace Timbl {
   }
 
   struct childArgs{
-    TimblServer *Mother;
+    ServerClass *Mother;
     Sockets::ServerSocket *socket;
     int maxC;
     map<string, TimblExperiment*> *experiments;
@@ -263,7 +268,7 @@ namespace Timbl {
     rest = string( m_it, line.end() );
   }  
 
-  bool TimblServer::doSetOptions( TimblExperiment *Exp, const string& Line ){
+  bool ServerClass::doSetOptions( TimblExperiment *Exp, const string& Line ){
     if ( Exp->SetOptions( Line ) ){
       if ( doDebug() )
 	*Log(myLog) << ": Command :" << Line << endl;
@@ -279,7 +284,7 @@ namespace Timbl {
     return true;
   }
 
-  bool TimblServer::classifyOneLine( TimblExperiment *Exp, 
+  bool ServerClass::classifyOneLine( TimblExperiment *Exp, 
 				     const string& params ){
     double Distance;
     string Distrib;
@@ -321,12 +326,12 @@ namespace Timbl {
   }
 
 #ifdef HAVE_DAEMON
-  int TimblServer::daemonize( int noCD , int noClose ){
+  int ServerClass::daemonize( int noCD , int noClose ){
     return daemon( noCD, noClose );
   }
 #else
   
-  int TimblServer::daemonize( int noCD , int noClose ){
+  int ServerClass::daemonize( int noCD , int noClose ){
     switch (fork()) {
     case -1:
       /* error */
@@ -374,7 +379,7 @@ namespace Timbl {
     string Line;
     Sockets::ServerSocket *sock = args->socket;
     int sockId = sock->getSockId();
-    TimblServer *theServer = args->Mother;
+    ServerClass *theServer = args->Mother;
     TimblExperiment *Chld = 0;
     signal( SIGPIPE, BrokenPipeChildFun );
 
@@ -390,7 +395,7 @@ namespace Timbl {
       // report connection to the server terminal
       //
       char line[256];
-      sprintf( line, "Thread %lu, on Socket %d", (uintptr_t)pthread_self(),
+      sprintf( line, "Thread %zd, on Socket %d", (uintptr_t)pthread_self(),
 	       sockId );
       *Log(theServer->myLog) << line << ", started." << endl;  
     }
@@ -432,7 +437,7 @@ namespace Timbl {
 	    // report connection to the server terminal
 	    //
 	    char line[256];
-	    sprintf( line, "Thread %lu, on Socket %d", 
+	    sprintf( line, "Thread %zd, on Socket %d", 
 		     (uintptr_t)pthread_self(), sockId );
 	    *Log(theServer->myLog) << line << ", started." << endl;  
 	  }
@@ -496,7 +501,7 @@ namespace Timbl {
   // ***** This is the routine that is executed from a new TCP thread *******
   void *socketChild( void *arg ){
     childArgs *args = (childArgs *)arg;
-    TimblServer *theServer = args->Mother;
+    ServerClass *theServer = args->Mother;
     static int service_count=0;
 
     static pthread_mutex_t my_lock = PTHREAD_MUTEX_INITIALIZER;
@@ -527,7 +532,7 @@ namespace Timbl {
     return NULL;
   }
 
-  void TimblServer::RunClassicServer(){
+  void ServerClass::RunClassicServer(){
     if ( !pidFile.empty() ){
       // check validity of pidfile
       if ( pidFile[0] != '/' ) // make sure the path is absolute
@@ -702,7 +707,7 @@ namespace Timbl {
   // ***** This is the routine that is executed from a new HTTP thread *******
   void *httpChild( void *arg ){
     childArgs *args = (childArgs *)arg;
-    TimblServer *theServer = args->Mother;
+    ServerClass *theServer = args->Mother;
     args->socket->setNonBlocking();
     int sockId = args->socket->getSockId(); 
     fdistream is(sockId);
@@ -727,7 +732,7 @@ namespace Timbl {
       // report connection to the server terminal
       //
       char logLine[256];
-      sprintf( logLine, "Thread %lu, on Socket %d", (uintptr_t)pthread_self(),
+      sprintf( logLine, "Thread %zd, on Socket %d", (uintptr_t)pthread_self(),
 	       sockId );
       *Log(theServer->myLog) << logLine << ", started." << endl;  
       signal( SIGPIPE, BrokenPipeChildFun );
@@ -918,7 +923,7 @@ namespace Timbl {
     return NULL;
   }
   
-  void TimblServer::RunHttpServer(){
+  void ServerClass::RunHttpServer(){
     if ( !pidFile.empty() ){
       // check validity of pidfile
       if ( pidFile[0] != '/' ) // make sure the path is absolute
@@ -1055,7 +1060,7 @@ namespace Timbl {
   }
   
   
-  bool TimblServer::startClassicServer( int port , int maxC ){
+  bool ServerClass::startClassicServer( int port , int maxC ){
     serverPort = port;
     if ( maxC > 0 )
       maxConn = maxC;
@@ -1077,7 +1082,7 @@ namespace Timbl {
     return false;
   }
 
-  bool TimblServer::startMultiServer( const string& config ){
+  bool ServerClass::startMultiServer( const string& config ){
     if ( exp && exp->ConfirmOptions() ){
       if ( getConfig( config ) ){
 	if ( serverProtocol == "http" ){
